@@ -4,31 +4,35 @@ import re
 import sys
 
 
-def expand_tabs(l, tabwidth=8):
+def expand_tabs(line, tabwidth=8):
     ret = []
-    for i, c in enumerate(l):
-        if l[i:i+1] == b'\t':
+    for i, c in enumerate(line):
+        if line[i:i+1] == b'\t':
             # Round up to the next unit of tabwidth
             ret.extend([b' '] * (tabwidth - len(ret) % tabwidth))
         else:
-            ret.append(l[i:i+1])
+            ret.append(line[i:i+1])
     return b''.join(ret)
 
 
-def whitespace_prefix_length(l):
-    return len(re.match(b'^\\s*', l).group(0))
+def whitespace_prefix_length(line):
+    return len(re.match(b'^\\s*', line).group(0))
 
 
-def value_offset(l):
-    if not l.strip():
+def value_offset(line):
+    if not line.strip():
         return None
-    if l.startswith(b'#'):
+    if line.startswith(b'#'):
         return None
-    if l[0:1] in (b'\t', b' '):
-        return whitespace_prefix_length(l)
+    if line[0:1] in (b'\t', b' '):
+        return whitespace_prefix_length(line)
     else:
-        key, value = l.split(b':', 1)
-        return len(key) + 1 + whitespace_prefix_length(value)
+        try:
+            key, value = line.split(b':', 1)
+        except ValueError:
+            return None
+        else:
+            return len(key) + 1 + whitespace_prefix_length(value)
 
 
 EXPECTED_HEADER = (
@@ -48,6 +52,7 @@ try:
     with open('debian/copyright', 'rb') as f:
         line = f.readline()
         if line.rstrip().rstrip(b'/') != EXPECTED_HEADER:
+            # Not a machine-readable copyright file
             sys.exit(0)
         lines.append(line)
         prev_value_offset = None
@@ -88,7 +93,7 @@ if tabs_replaced:
     sys.stdout.write('use spaces rather than tabs to start continuation lines')
     if unicode_linebreaks_replaced:
         sys.stdout.write(', ')
-    tags.add('tab-in-licence-text')
+    tags.add('tab-in-license-text')
 if unicode_linebreaks_replaced:
     sys.stdout.write('replace unicode linebreaks with regular linebreaks')
 sys.stdout.write('.\n')
